# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class Duration(object):
    """
    Struct Class

    represents a duration.
    
    A duration is the difference of 2 DateTimes.
    
    Note that there are no constraints on the ranges of the members, except that every member must be non-negative: for example, a Duration of 400 Days is valid.
    
    **since**
    
        OOo 3.3

    See Also:
        `API Duration <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1Duration.html>`_
    """
    typeName: Literal['com.sun.star.util.Duration']

    def __init__(self, Negative: typing.Optional[bool] = ..., Years: typing.Optional[int] = ..., Months: typing.Optional[int] = ..., Days: typing.Optional[int] = ..., Hours: typing.Optional[int] = ..., Minutes: typing.Optional[int] = ..., Seconds: typing.Optional[int] = ..., NanoSeconds: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Negative (bool, optional): Negative value.
            Years (int, optional): Years value.
            Months (int, optional): Months value.
            Days (int, optional): Days value.
            Hours (int, optional): Hours value.
            Minutes (int, optional): Minutes value.
            Seconds (int, optional): Seconds value.
            NanoSeconds (int, optional): NanoSeconds value.
        """


    @property
    def Negative(self) -> bool:
        """
        explicit sign bit.
        """


    @property
    def Years(self) -> int:
        """
        contains the years.
        """


    @property
    def Months(self) -> int:
        """
        contains the months.
        """


    @property
    def Days(self) -> int:
        """
        contains the days.
        """


    @property
    def Hours(self) -> int:
        """
        contains the hours.
        """


    @property
    def Minutes(self) -> int:
        """
        contains the minutes.
        """


    @property
    def Seconds(self) -> int:
        """
        contains the seconds.
        """


    @property
    def NanoSeconds(self) -> int:
        """
        contains the nanoseconds.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.script
from typing_extensions import Literal
from .x_library_container import XLibraryContainer as XLibraryContainer_daa0e6d

class XLibraryContainer2(XLibraryContainer_daa0e6d):
    """
    Extension of XLibraryContainer to provide additional information about the libraries contained in a library container.

    See Also:
        `API XLibraryContainer2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XLibraryContainer2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.script.XLibraryContainer2']

    def getLibraryLinkURL(self, Name: str) -> str:
        """
        returns the location of the library link target.
        
        Should return the same URL that was passed to createLibraryLink in the StorageURL parameter.
        
        If the accessed library item exists but isn't a link, an IllegalArgumentException is thrown

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    def isLibraryLink(self, Name: str) -> bool:
        """
        returns true if the accessed library item is a link, e.g., created by createLibraryLink, otherwise false.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    def isLibraryReadOnly(self, Name: str) -> bool:
        """
        returns true if the accessed library item (library or library link) is read only.
        
        A library can be read only because it was set to read only using the methods provided by this interface or because of other reasons depending on the implementation (e.g., file system write protection)

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    def renameLibrary(self, Name: str, NewName: str) -> None:
        """
        renames the library item with the specified name.
        
        If the accessed library item is a link only the link is renamed, not the target library. If a library with the new name exists already a com.sun.star.container.ElementExistException is thrown.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
    def setLibraryReadOnly(self, Name: str, bReadOnly: bool) -> None:
        """
        Sets the accessed library item (library or library link) to read only according to the flag bReadOnly (true means read only)

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class ScriptEventDescriptor(object):
    """
    Struct Class

    describes an effect, especially a script to be executed, for a certain event given by the listener type and the name of the event method.

    See Also:
        `API ScriptEventDescriptor <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1script_1_1ScriptEventDescriptor.html>`_
    """
    typeName: Literal['com.sun.star.script.ScriptEventDescriptor']

    def __init__(self, ListenerType: typing.Optional[str] = ..., EventMethod: typing.Optional[str] = ..., AddListenerParam: typing.Optional[str] = ..., ScriptType: typing.Optional[str] = ..., ScriptCode: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            ListenerType (str, optional): ListenerType value.
            EventMethod (str, optional): EventMethod value.
            AddListenerParam (str, optional): AddListenerParam value.
            ScriptType (str, optional): ScriptType value.
            ScriptCode (str, optional): ScriptCode value.
        """


    @property
    def ListenerType(self) -> str:
        """
        listener type as string, same as listener-XIdlClass.getName().
        """


    @property
    def EventMethod(self) -> str:
        """
        event method as string.
        """


    @property
    def AddListenerParam(self) -> str:
        """
        data to be used if the addListener method needs an additional parameter.
        
        If the type of this parameter is different from string, it will be converted, when added.
        """


    @property
    def ScriptType(self) -> str:
        """
        type of the script language as string; for example, \"Basic\" or \"StarScript\".
        """


    @property
    def ScriptCode(self) -> str:
        """
        script code as string (the code has to correspond with the language defined by ScriptType).
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.datatransfer.dnd
# Libre Office Version: 7.2
from typing_extensions import Literal
from ...lang.event_object import EventObject as EventObject_a3d70b03
from ...uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .x_drag_source import XDragSource as XDragSource_49900fb2


class DragGestureEvent(EventObject_a3d70b03):
    """
    Struct Class

    A DragGestureEvent is passed to the method XDragGestureListener.dragGestureRecognized() when a particular XDragGestureRecognizer detects that a platform dependent drag initiating gesture has occurred on the component that it is tracking.

    See Also:
        `API DragGestureEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1DragGestureEvent.html>`_
    """
    typeName: Literal['com.sun.star.datatransfer.dnd.DragGestureEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., DragAction: typing.Optional[int] = ..., DragOriginX: typing.Optional[int] = ..., DragOriginY: typing.Optional[int] = ..., DragSource: typing.Optional[XDragSource_49900fb2] = ..., Event: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            DragAction (int, optional): DragAction value.
            DragOriginX (int, optional): DragOriginX value.
            DragOriginY (int, optional): DragOriginY value.
            DragSource (XDragSource, optional): DragSource value.
            Event (object, optional): Event value.
        """


    @property
    def DragAction(self) -> int:
        """
        The action selected by the user.
        
        Different constants may be combined using a logical OR.
        
        It's further possible to combine the ACTION_DEFAULT with one of the other actions defined in com.sun.star.datatransfer.dnd.DNDConstants. This means the user did not press any key during the Drag and Drop operation and the action that was combined with ACTION_DEFAULT is the system default action.
        """


    @property
    def DragOriginX(self) -> int:
        """
        The x coordinate where the drag originated in component coordinates.
        """


    @property
    def DragOriginY(self) -> int:
        """
        The y coordinate where the drag originated in component coordinates.
        """


    @property
    def DragSource(self) -> XDragSource_49900fb2:
        """
        The DragSource associated with this drag action.
        """


    @property
    def Event(self) -> object:
        """
        The last event comprising the gesture.
        
        The initial trigger event will presumably be a com.sun.star.awt.MouseEvent event. If it is not, the implementation should either react accordingly or presume that the left mouse button was clicked.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xforms
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from ..frame.x_model import XModel as XModel_7a6e095c
    from .x_model import XModel as XModel_865909f0
    from ..xml.dom.x_document import XDocument as XDocument_aebc0b5e
    from ..xml.dom.x_node import XNode as XNode_83fb09a5

class XFormsUIHelper1(ABC):
    """
    provide several helper methods for the UI
    
    This interfaces is for UI use only, and will likely be unsupported in future versions.

    See Also:
        `API XFormsUIHelper1 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xforms_1_1XFormsUIHelper1.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xforms.XFormsUIHelper1']

    def cloneBindingAsGhost(self, binding: 'XPropertySet_bc180bfa') -> 'XPropertySet_bc180bfa':
        """
        """
    def createAttribute(self, xParent: 'XNode_83fb09a5', sName: str) -> 'XNode_83fb09a5':
        """
        """
    def createElement(self, xParent: 'XNode_83fb09a5', sName: str) -> 'XNode_83fb09a5':
        """
        """
    def getBindingForNode(self, xNode: 'XNode_83fb09a5', bCreate: bool) -> 'XPropertySet_bc180bfa':
        """
        """
    def getBindingName(self, xBinding: 'XPropertySet_bc180bfa', bDetail: bool) -> str:
        """
        """
    def getDefaultBindingExpressionForNode(self, xNode: 'XNode_83fb09a5') -> str:
        """
        """
    def getDefaultServiceNameForNode(self, xNode: 'XNode_83fb09a5') -> str:
        """
        """
    def getNodeDisplayName(self, xNode: 'XNode_83fb09a5', bDetail: bool) -> str:
        """
        """
    def getNodeName(self, xNode: 'XNode_83fb09a5') -> str:
        """
        """
    def getResultForExpression(self, xBinding: 'XPropertySet_bc180bfa', bIsBindingExpression: bool, sExpression: str) -> str:
        """
        """
    def getSubmissionName(self, xSubm: 'XPropertySet_bc180bfa', bDetail: bool) -> str:
        """
        """
    def isValidPrefixName(self, sName: str) -> bool:
        """
        """
    def isValidXMLName(self, sName: str) -> bool:
        """
        """
    def newInstance(self, sName: str, sURL: str, bURLOnce: bool) -> 'XDocument_aebc0b5e':
        """
        """
    def newModel(self, xModel: 'XModel_7a6e095c', sName: str) -> 'XModel_865909f0':
        """
        """
    def removeBindingForNode(self, xNode: 'XNode_83fb09a5') -> None:
        """
        """
    def removeBindingIfUseless(self, xBinding: 'XPropertySet_bc180bfa') -> None:
        """
        """
    def removeInstance(self, sName: str) -> None:
        """
        """
    def removeModel(self, xModel: 'XModel_7a6e095c', sName: str) -> None:
        """
        """
    def renameInstance(self, sFrom: str, sTo: str, sURL: str, bURLOnce: bool) -> None:
        """
        """
    def renameModel(self, xModel: 'XModel_7a6e095c', sFrom: str, sTo: str) -> None:
        """
        """
    def renameNode(self, xNode: 'XNode_83fb09a5', sName: str) -> 'XNode_83fb09a5':
        """
        """
    def setNodeValue(self, xNode: 'XNode_83fb09a5', sValue: str) -> None:
        """
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.sdbc.batch_update_exception import BatchUpdateException as BatchUpdateException
from .._pyi.sdbc.callable_statement import CallableStatement as CallableStatement
from .._pyi.sdbc.change_event import ChangeEvent as ChangeEvent
from .._pyi.sdbc.connection import Connection as Connection
from .._pyi.sdbc.connection_pool import ConnectionPool as ConnectionPool
from .._pyi.sdbc.connection_properties import ConnectionProperties as ConnectionProperties
from .._pyi.sdbc.dbase_connection_properties import DBASEConnectionProperties as DBASEConnectionProperties
from .._pyi.sdbc.data_truncation import DataTruncation as DataTruncation
from .._pyi.sdbc.driver import Driver as Driver
from .._pyi.sdbc.driver_manager import DriverManager as DriverManager
from .._pyi.sdbc.driver_property_info import DriverPropertyInfo as DriverPropertyInfo
from .._pyi.sdbc.file_connection_properties import FILEConnectionProperties as FILEConnectionProperties
from .._pyi.sdbc.flat_connection_properties import FLATConnectionProperties as FLATConnectionProperties
from .._pyi.sdbc.jdbc_connection_properties import JDBCConnectionProperties as JDBCConnectionProperties
from .._pyi.sdbc.odbc_connection_properties import ODBCConnectionProperties as ODBCConnectionProperties
from .._pyi.sdbc.prepared_statement import PreparedStatement as PreparedStatement
from .._pyi.sdbc.result_set import ResultSet as ResultSet
from .._pyi.sdbc.row_set import RowSet as RowSet
from .._pyi.sdbc.sql_exception import SQLException as SQLException
from .._pyi.sdbc.sql_warning import SQLWarning as SQLWarning
from .._pyi.sdbc.statement import Statement as Statement
from .._pyi.sdbc.x_array import XArray as XArray
from .._pyi.sdbc.x_batch_execution import XBatchExecution as XBatchExecution
from .._pyi.sdbc.x_blob import XBlob as XBlob
from .._pyi.sdbc.x_clob import XClob as XClob
from .._pyi.sdbc.x_closeable import XCloseable as XCloseable
from .._pyi.sdbc.x_column_locate import XColumnLocate as XColumnLocate
from .._pyi.sdbc.x_connection import XConnection as XConnection
from .._pyi.sdbc.x_connection_pool import XConnectionPool as XConnectionPool
from .._pyi.sdbc.x_data_source import XDataSource as XDataSource
from .._pyi.sdbc.x_database_meta_data import XDatabaseMetaData as XDatabaseMetaData
from .._pyi.sdbc.x_database_meta_data2 import XDatabaseMetaData2 as XDatabaseMetaData2
from .._pyi.sdbc.x_driver import XDriver as XDriver
from .._pyi.sdbc.x_driver_access import XDriverAccess as XDriverAccess
from .._pyi.sdbc.x_driver_manager import XDriverManager as XDriverManager
from .._pyi.sdbc.x_driver_manager2 import XDriverManager2 as XDriverManager2
from .._pyi.sdbc.x_generated_result_set import XGeneratedResultSet as XGeneratedResultSet
from .._pyi.sdbc.x_isolated_connection import XIsolatedConnection as XIsolatedConnection
from .._pyi.sdbc.x_multiple_results import XMultipleResults as XMultipleResults
from .._pyi.sdbc.x_out_parameters import XOutParameters as XOutParameters
from .._pyi.sdbc.x_parameters import XParameters as XParameters
from .._pyi.sdbc.x_pooled_connection import XPooledConnection as XPooledConnection
from .._pyi.sdbc.x_prepared_batch_execution import XPreparedBatchExecution as XPreparedBatchExecution
from .._pyi.sdbc.x_prepared_statement import XPreparedStatement as XPreparedStatement
from .._pyi.sdbc.x_ref import XRef as XRef
from .._pyi.sdbc.x_result_set import XResultSet as XResultSet
from .._pyi.sdbc.x_result_set_meta_data import XResultSetMetaData as XResultSetMetaData
from .._pyi.sdbc.x_result_set_meta_data_supplier import XResultSetMetaDataSupplier as XResultSetMetaDataSupplier
from .._pyi.sdbc.x_result_set_update import XResultSetUpdate as XResultSetUpdate
from .._pyi.sdbc.x_row import XRow as XRow
from .._pyi.sdbc.x_row_set import XRowSet as XRowSet
from .._pyi.sdbc.x_row_set_listener import XRowSetListener as XRowSetListener
from .._pyi.sdbc.x_row_update import XRowUpdate as XRowUpdate
from .._pyi.sdbc.xsql_data import XSQLData as XSQLData
from .._pyi.sdbc.xsql_input import XSQLInput as XSQLInput
from .._pyi.sdbc.xsql_output import XSQLOutput as XSQLOutput
from .._pyi.sdbc.x_statement import XStatement as XStatement
from .._pyi.sdbc.x_struct import XStruct as XStruct
from .._pyi.sdbc.x_warnings_supplier import XWarningsSupplier as XWarningsSupplier



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
import typing
from .base_frame import BaseFrame as BaseFrame_8f020a33
if typing.TYPE_CHECKING:
    from ..awt.size import Size as Size_576707ef
    from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
    from ..drawing.color_mode import ColorMode as ColorMode_b13e0b78
    from ..drawing.point_sequence_sequence import PointSequenceSequence as PointSequenceSequence_5c591070
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from .graphic_crop import GraphicCrop as GraphicCrop_a58e0b1f

class TextGraphicObject(BaseFrame_8f020a33):
    """
    Service Class

    specifies a graphic which can be embedded in Text.

    See Also:
        `API TextGraphicObject <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html>`_
    """
    @property
    def ActualSize(self) -> 'Size_576707ef':
        """
        contains the original size of the bitmap in the graphic object.
        """
    @property
    def AdjustBlue(self) -> int:
        """
        changes the display of the blue color channel.
        
        It contains percentage values between -100 and +100.
        """
    @property
    def AdjustContrast(self) -> int:
        """
        changes the display of contrast.
        
        It contains percentage values between -100 and +100.
        """
    @property
    def AdjustGreen(self) -> int:
        """
        changes the display of the green color channel.
        
        It contains percentage values between -100 and +100.
        """
    @property
    def AdjustLuminance(self) -> int:
        """
        changes the display of the luminance.
        
        It contains percentage values between -100 and +100.
        """
    @property
    def AdjustRed(self) -> int:
        """
        changes the display of the red color channel.
        
        It contains percentage values between -100 and +100.
        """
    @property
    def ContentProtected(self) -> bool:
        """
        determines if the content is protected against changes from the user interface.
        """
    @property
    def ContourOutside(self) -> bool:
        """
        the text flows only around the contour of the object.
        """
    @property
    def ContourPolyPolygon(self) -> 'PointSequenceSequence_5c591070':
        """
        contains the contour of the object as PolyPolygon.
        """
    @property
    def Gamma(self) -> float:
        """
        determines the gamma value of the graphic.
        """
    @property
    def Graphic(self) -> 'XGraphic_a4da0afc':
        """
        contains the background graphic of the object.
        """
    @property
    def GraphicColorMode(self) -> 'ColorMode_b13e0b78':
        """
        contains the ColorMode as com.sun.star.drawing.ColorMode.
        """
    @property
    def GraphicCrop(self) -> 'GraphicCrop_a58e0b1f':
        """
        contains the cropping of the object.
        """
    @property
    def GraphicFilter(self) -> str:
        """
        contains the name of the filter of the background graphic of the object.
        """
    @property
    def GraphicIsInverted(self) -> bool:
        """
        determines if the graphic is display in inverted colors.
        
        It contains percentage values between -100 and +100.
        """
    @property
    def GraphicURL(self) -> str:
        """
        contains the URL of the background graphic of the object
        
        Note the new behaviour since it was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When a URL is set, then it will load the image and set the Graphic property.
        """
    @property
    def HoriMirroredOnEvenPages(self) -> bool:
        """
        determines if the object is horizontally mirrored on even pages.
        """
    @property
    def HoriMirroredOnOddPages(self) -> bool:
        """
        determines if the object is horizontally mirrored on odd pages.
        """
    @property
    def ImageMap(self) -> 'XIndexContainer_1c040ebe':
        """
        returns the client-side image map if one is assigned to the object.
        """
    @property
    def SurroundContour(self) -> bool:
        """
        determines if the text wraps around the contour of the object.
        """
    @property
    def Transparency(self) -> int:
        """
        contains percentage values between -100 and +100.
        """
    @property
    def VertMirrored(self) -> bool:
        """
        determines if the object is mirrored vertically.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.i18n
from typing_extensions import Literal


class Weekdays(object):
    """
    Const

    Constants for days of a week.
    
    used with XCalendar.getFirstDayOfWeek(), XCalendar.setFirstDayOfWeek() and XCalendar.getDisplayName()

    See Also:
        `API Weekdays <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1Weekdays.html>`_
    """
    SUNDAY: Literal[0]
    """
    Sunday.
    """
    MONDAY: Literal[1]
    """
    Monday.
    """
    TUESDAY: Literal[2]
    """
    Tuesday.
    """
    WEDNESDAY: Literal[3]
    """
    Wednesday.
    """
    THURSDAY: Literal[4]
    """
    Thursday.
    """
    FRIDAY: Literal[5]
    """
    Friday.
    """
    SATURDAY: Literal[6]
    """
    Saturday.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.i18n
from typing_extensions import Literal


class TextConversionOption(object):
    """
    Const

    Text conversion options to be used with XTextConversion.
    
    These text conversion options are usually selected by end users. The options can be combined and may be related to TextConversionType.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API TextConversionOption <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1TextConversionOption.html>`_
    """
    NONE: Literal[0]
    """
    No option.
    """
    CHARACTER_BY_CHARACTER: Literal[1]
    """
    Character by character conversion.
    """
    IGNORE_POST_POSITIONAL_WORD: Literal[2]
    """
    Ignore post-positional word for Hangul to Hanja conversion.
    """
    USE_CHARACTER_VARIANTS: Literal[2]
    """
    Use Taiwan, HongKong SAR, and Macao SAR character variants for Simplified to Traditional Chinese conversion.
    
    **since**
    
        OOo 2.0
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class LanguageCountryInfo(object):
    """
    Struct Class

    The language and country identifiers and descriptive names of the loaded locale data returned by XLocaleData.getLanguageCountryInfo().

    See Also:
        `API LanguageCountryInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1LanguageCountryInfo.html>`_
    """
    typeName: Literal['com.sun.star.i18n.LanguageCountryInfo']

    def __init__(self, Language: typing.Optional[str] = ..., LanguageDefaultName: typing.Optional[str] = ..., Country: typing.Optional[str] = ..., CountryDefaultName: typing.Optional[str] = ..., Variant: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Language (str, optional): Language value.
            LanguageDefaultName (str, optional): LanguageDefaultName value.
            Country (str, optional): Country value.
            CountryDefaultName (str, optional): CountryDefaultName value.
            Variant (str, optional): Variant value.
        """


    @property
    def Language(self) -> str:
        """
        ISO-639 language code, for example, \"en\" or \"de\".
        """


    @property
    def LanguageDefaultName(self) -> str:
        """
        Descriptive language name, for example, \"English\" or \"German\".
        """


    @property
    def Country(self) -> str:
        """
        ISO-3166 country code, for example, \"US\" or \"DE\".
        """


    @property
    def CountryDefaultName(self) -> str:
        """
        Descriptive country name, for example, \"United States\" or \"Germany\".
        """


    @property
    def Variant(self) -> str:
        """
        A variant name.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.inspection
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .x_property_control import XPropertyControl as XPropertyControl_3f260fe2
    from .x_property_control_observer import XPropertyControlObserver as XPropertyControlObserver_cc6d132a

class XObjectInspectorUI(ABC):
    """
    grants access to certain aspects of the user interface of an object inspector
    
    This interface is used as callback for XPropertyHandlers.
    
    As a consequence, methods operating on the UI for a property, and taking the name of this property, are tolerant against properties which do not exist. For instance, if a property handler tries to disable the UI for property Foo, but another handler has superseded this property, then the ObjectInspector will not have any UI for it. In this case, the call to enablePropertyUI( \"Foo\" ) will simply be ignored.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API XObjectInspectorUI <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1inspection_1_1XObjectInspectorUI.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.inspection.XObjectInspectorUI']

    def enablePropertyUI(self, PropertyName: str, Enable: bool) -> None:
        """
        enables or disables all components belonging to the UI representation of a property
        
        This is usually used by an XPropertyHandler if it handles properties, where one does only make sense if another one has a certain value.
        """
    def enablePropertyUIElements(self, PropertyName: str, Elements: int, Enable: bool) -> None:
        """
        enables or disables the single elements which can be part of the UI representation of a property
        
        Note that the complete UI for the property must be enabled in order for these settings to be evaluated. That is, enablePropertyUIElements() does not have any effect if somebody previously disabled the complete UI for this property with enablePropertyUI().
        """
    def getPropertyControl(self, PropertyName: str) -> 'XPropertyControl_3f260fe2':
        """
        retrieves the control currently used to display a given property
        """
    def hidePropertyUI(self, PropertyName: str) -> None:
        """
        hides the UI for a given property
        """
    def rebuildPropertyUI(self, PropertyName: str) -> None:
        """
        completely rebuilds the UI for the given property.
        
        This method might be used by an XPropertyHandler if it wants to change the type of control (see PropertyControlType) used to display a certain property.
        
        The object inspector will then call describePropertyLine again, and update its UI accordingly.
        
        Note that the property whose UI should be rebuilt must not necessarily be (though usually is) in the responsibility of the handler which calls this method. The object inspector will look up the handler with the responsibility for PropertyName and call its XPropertyHandler.describePropertyLine()
        """
    def registerControlObserver(self, Observer: 'XPropertyControlObserver_cc6d132a') -> None:
        """
        registers an observer for all property controls
        
        The given XPropertyControlObserver will be notified of all changes in all property controls.
        
        **since**
        
            OOo 2.2
        """
    def revokeControlObserver(self, Observer: 'XPropertyControlObserver_cc6d132a') -> None:
        """
        revokes a previously registered control observer
        
        **since**
        
            OOo 2.2
        """
    def setHelpSectionText(self, HelpText: str) -> None:
        """
        sets the text of the help section, if the object inspector contains one.
        
        **since**
        
            OOo 2.2

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
    def showCategory(self, Category: str, Show: bool) -> None:
        """
        shows or hides all properties belonging to a given category
        """
    def showPropertyUI(self, PropertyName: str) -> None:
        """
        shows the UI for a given property
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.animations
from typing_extensions import Literal


class TransitionSubType(object):
    """
    Const


    See Also:
        `API TransitionSubType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html>`_
    """
    DEFAULT: Literal[0]
    LEFTTORIGHT: Literal[1]
    TOPTOBOTTOM: Literal[2]
    TOPLEFT: Literal[3]
    TOPRIGHT: Literal[4]
    BOTTOMRIGHT: Literal[5]
    BOTTOMLEFT: Literal[6]
    TOPCENTER: Literal[7]
    RIGHTCENTER: Literal[8]
    BOTTOMCENTER: Literal[9]
    LEFTCENTER: Literal[10]
    CORNERSIN: Literal[11]
    CORNERSOUT: Literal[12]
    VERTICAL: Literal[13]
    HORIZONTAL: Literal[14]
    DIAGONALBOTTOMLEFT: Literal[15]
    DIAGONALTOPLEFT: Literal[16]
    DOUBLEBARNDOOR: Literal[17]
    DOUBLEDIAMOND: Literal[18]
    DOWN: Literal[19]
    LEFT: Literal[20]
    UP: Literal[21]
    RIGHT: Literal[22]
    RECTANGLE: Literal[25]
    DIAMOND: Literal[26]
    CIRCLE: Literal[27]
    FOURPOINT: Literal[28]
    FIVEPOINT: Literal[29]
    SIXPOINT: Literal[30]
    HEART: Literal[31]
    KEYHOLE: Literal[32]
    CLOCKWISETWELVE: Literal[33]
    CLOCKWISETHREE: Literal[34]
    CLOCKWISESIX: Literal[35]
    CLOCKWISENINE: Literal[36]
    TWOBLADEVERTICAL: Literal[37]
    TWOBLADEHORIZONTAL: Literal[38]
    FOURBLADE: Literal[39]
    CLOCKWISETOP: Literal[40]
    CLOCKWISERIGHT: Literal[41]
    CLOCKWISEBOTTOM: Literal[42]
    CLOCKWISELEFT: Literal[43]
    CLOCKWISETOPLEFT: Literal[44]
    COUNTERCLOCKWISEBOTTOMLEFT: Literal[45]
    CLOCKWISEBOTTOMRIGHT: Literal[46]
    COUNTERCLOCKWISETOPRIGHT: Literal[47]
    CENTERTOP: Literal[48]
    CENTERRIGHT: Literal[49]
    TOP: Literal[50]
    BOTTOM: Literal[52]
    FANOUTVERTICAL: Literal[54]
    FANOUTHORIZONTAL: Literal[55]
    FANINVERTICAL: Literal[56]
    FANINHORIZONTAL: Literal[57]
    PARALLELVERTICAL: Literal[58]
    PARALLELDIAGONAL: Literal[59]
    OPPOSITEVERTICAL: Literal[60]
    OPPOSITEHORIZONTAL: Literal[61]
    PARALLELDIAGONALTOPLEFT: Literal[62]
    PARALLELDIAGONALBOTTOMLEFT: Literal[63]
    TOPLEFTHORIZONTAL: Literal[64]
    TOPLEFTDIAGONAL: Literal[65]
    TOPRIGHTDIAGONAL: Literal[66]
    BOTTOMRIGHTDIAGONAL: Literal[67]
    BOTTOMLEFTDIAGONAL: Literal[68]
    TOPLEFTCLOCKWISE: Literal[69]
    TOPRIGHTCLOCKWISE: Literal[70]
    BOTTOMRIGHTCLOCKWISE: Literal[71]
    BOTTOMLEFTCLOCKWISE: Literal[72]
    TOPLEFTCOUNTERCLOCKWISE: Literal[73]
    TOPRIGHTCOUNTERCLOCKWISE: Literal[74]
    BOTTOMRIGHTCOUNTERCLOCKWISE: Literal[75]
    BOTTOMLEFTCOUNTERCLOCKWISE: Literal[76]
    VERTICALTOPSAME: Literal[77]
    VERTICALBOTTOMSAME: Literal[78]
    VERTICALTOPLEFTOPPOSITE: Literal[79]
    VERTICALBOTTOMLEFTOPPOSITE: Literal[80]
    HORIZONTALLEFTSAME: Literal[81]
    HORIZONTALRIGHTSAME: Literal[82]
    HORIZONTALTOPLEFTOPPOSITE: Literal[83]
    HORIZONTALTOPRIGHTOPPOSITE: Literal[84]
    DIAGONALBOTTOMLEFTOPPOSITE: Literal[85]
    DIAGONALTOPLEFTOPPOSITE: Literal[86]
    TWOBOXTOP: Literal[87]
    TWOBOXBOTTOM: Literal[88]
    TWOBOXLEFT: Literal[89]
    TWOBOXRIGHT: Literal[90]
    FOURBOXVERTICAL: Literal[91]
    FOURBOXHORIZONTAL: Literal[92]
    VERTICALLEFT: Literal[93]
    VERTICALRIGHT: Literal[94]
    HORIZONTALLEFT: Literal[95]
    HORIZONTALRIGHT: Literal[96]
    FROMLEFT: Literal[97]
    FROMTOP: Literal[98]
    FROMRIGHT: Literal[99]
    FROMBOTTOM: Literal[100]
    CROSSFADE: Literal[101]
    FADETOCOLOR: Literal[102]
    FADEFROMCOLOR: Literal[103]
    FADEOVERCOLOR: Literal[104]
    THREEBLADE: Literal[105]
    EIGHTBLADE: Literal[106]
    ONEBLADE: Literal[107]
    ACROSS: Literal[108]
    TOPLEFTVERTICAL: Literal[109]
    COMBHORIZONTAL: Literal[110]
    COMBVERTICAL: Literal[111]
    IN: Literal[112]
    OUT: Literal[113]
    ROTATEIN: Literal[114]
    ROTATEOUT: Literal[115]
    FROMTOPLEFT: Literal[116]
    FROMTOPRIGHT: Literal[117]
    FROMBOTTOMLEFT: Literal[118]
    FROMBOTTOMRIGHT: Literal[119]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..util.color import Color as Color_68e908c5


class FilterFieldValue(object):
    """
    Struct Class

    
    **since**
    
        LibreOffice 3.5

    See Also:
        `API FilterFieldValue <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1FilterFieldValue.html>`_
    """
    typeName: Literal['com.sun.star.sheet.FilterFieldValue']

    def __init__(self, IsNumeric: typing.Optional[bool] = ..., NumericValue: typing.Optional[float] = ..., StringValue: typing.Optional[str] = ..., FilterType: typing.Optional[int] = ..., ColorValue: typing.Optional[Color_68e908c5] = ...) -> None:
        """
        Constructor

        Arguments:
            IsNumeric (bool, optional): IsNumeric value.
            NumericValue (float, optional): NumericValue value.
            StringValue (str, optional): StringValue value.
            FilterType (int, optional): FilterType value.
            ColorValue (Color, optional): ColorValue value.
        """


    @property
    def IsNumeric(self) -> bool:
        """
        selects whether the TableFilterFieldValue.NumericValue or the TableFilterFieldValue.StringValue is used.
        """


    @property
    def NumericValue(self) -> float:
        """
        specifies a numeric value for the condition.
        """


    @property
    def StringValue(self) -> str:
        """
        specifies a string value for the condition.
        """


    @property
    def FilterType(self) -> int:
        """
        Which field should be used for filtering:
        
        **since**
        
            LibreOffice 7.2
        """


    @property
    def ColorValue(self) -> Color_68e908c5:
        """
        The color which is used for filtering.
        
        **since**
        
            LibreOffice 7.2
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.bridge
from .x_bridge_supplier import XBridgeSupplier as XBridgeSupplier_ede00d6e

class OleBridgeSupplier(XBridgeSupplier_ede00d6e):
    """
    Service Class

    makes it possible to generate OLE bridges to UNO objects and vice versa.
    
    The service implements the XBridgeSupplier interface and handles the model types ModelDependent.UNO and ModelDependent.OLE. The service does not specify any requirements on registering OLE objects and class factories.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API OleBridgeSupplier <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1bridge_1_1OleBridgeSupplier.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.inspection
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..awt.x_window import XWindow as XWindow_713b0924
    from .x_property_control_context import XPropertyControlContext as XPropertyControlContext_b94c12c7

class XPropertyControl(ABC):
    """
    defines the interface for a single control in an ObjectInspector
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API XPropertyControl <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1inspection_1_1XPropertyControl.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.inspection.XPropertyControl']

    def isModified(self) -> bool:
        """
        determines whether the control content is currently modified
        
        An XPropertyControl internally manages a flag indicating whether its content is modified. This flag is reset to FALSE every time our ControlContext is notified of our current value. Also, the control implementation must set this flag to TRUE if and only if the user changed the control content.
        """
    def notifyModifiedValue(self) -> None:
        """
        notifies the context in which the control lives of the current control value, if this value is currently modified
        """
    @property
    def ControlContext(self) -> 'XPropertyControlContext_b94c12c7':
        """
        specifies the context of the control within the ObjectInspector.
        
        The property control should actively notify its state changes to the context. In particular, changes in the focus and the value of the control must be notified.
        """

    @property
    def ControlType(self) -> int:
        """
        denotes the type of the control, as one of the PropertyControlType constants
        """

    @property
    def ControlWindow(self) -> 'XWindow_713b0924':
        """
        denotes the window which is the real UI representation of the property control.
        
        The ObjectInspector will automatically position and size this control as needed, care for its Z-order, and so on.
        
        This Window must not be NULL, else the whole control is not usable.
        """

    @property
    def Value(self) -> object:
        """
        denotes the current content of the control.
        
        At every point in time, this value is either VOID, or of the type described by ValueType.
        """

    @property
    def ValueType(self) -> object:
        """
        denotes the value type of the control.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class DataPilotTableHeaderData(object):
    """
    Struct Class

    information about a cell within the column or row header area of a DataPilot table.
    
    This struct contains information about a particular cell located within the column or row header area of a DataPilot table. This is the type that is contained in DataPilotTablePositionData.PositionData when the value of DataPilotTablePositionData.PositionType is either DataPilotTablePositionType.ROW_HEADER or DataPilotTablePositionType.COLUMN_HEADER.
    
    **since**
    
        OOo 3.0

    See Also:
        `API DataPilotTableHeaderData <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotTableHeaderData.html>`_
    """
    typeName: Literal['com.sun.star.sheet.DataPilotTableHeaderData']

    def __init__(self, Dimension: typing.Optional[int] = ..., Hierarchy: typing.Optional[int] = ..., Level: typing.Optional[int] = ..., Flags: typing.Optional[int] = ..., MemberName: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Dimension (int, optional): Dimension value.
            Hierarchy (int, optional): Hierarchy value.
            Level (int, optional): Level value.
            Flags (int, optional): Flags value.
            MemberName (str, optional): MemberName value.
        """


    @property
    def Dimension(self) -> int:
        """
        number of dimensions
        """


    @property
    def Hierarchy(self) -> int:
        """
        hierarchy
        """


    @property
    def Level(self) -> int:
        """
        level
        """


    @property
    def Flags(self) -> int:
        """
        flag
        """


    @property
    def MemberName(self) -> str:
        """
        member name
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rendering
from typing_extensions import Literal
"""
Const

Categories for color spaces.

See Also:
    `API ColorSpaceType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1ColorSpaceType.html>`_
"""
DEVICE_COLOR: Literal[0]
"""
Unspecified device color space - use conversion functions to convert to standard color spaces.
"""
GREY: Literal[1]
"""
Grey-value color space.

Use this for monochrome images.
"""
RGB: Literal[2]
"""
RGB color space.
"""
CMYK: Literal[3]
"""
CMYK color space.

See Wikipedia for a thorough explanation.
"""
CMYKOG: Literal[4]
"""
CMYKOG color space.

See Wikipedia for a thorough explanation.
"""
CIEXYZ: Literal[5]
"""
Standard CieXYZ color space.

See Wikipedia for a thorough explanation.
"""
CIELAB: Literal[6]
"""
Standard CieLab color space.

See Wikipedia for a thorough explanation. Preferable over CIEXYZ if perceptual uniformity is an issue.
"""
SRGB: Literal[7]
"""
Standard sRGB color space.

See Wikipedia for a thorough explanation.
"""
HSV: Literal[8]
"""
HSV color space.

Hue saturation value. See Wikipedia for a thorough explanation.
"""
HSL: Literal[9]
"""
HSL color space.

Hue saturation lightness. See Wikipedia for a thorough explanation
"""
YCBCR: Literal[10]
"""
YCbCr color space.

See Wikipedia for a thorough explanation. This color space is common for digital video.
"""
INDEXED: Literal[11]
"""
Indexed color space.

The color components of this color space are in fact indices into a color map.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..task.classified_interaction_request import ClassifiedInteractionRequest as ClassifiedInteractionRequest_9f72121b
from ..uno.x_interface import XInterface as XInterface_8f010a43
from ..task.interaction_classification import InteractionClassification as InteractionClassification_6c4d10e7

class NameClashResolveRequest(ClassifiedInteractionRequest_9f72121b):
    """
    Exception Class

    This request is used to indicate a name clash.
    
    For example, when copying a file there might be another file in the target folder that has the same file name as the source file.
    
    If this exception is passed to an com.sun.star.task.XInteractionHandler an XInteractionSupplyName and an XInteractionReplaceExistingData should be supplied with the com.sun.star.task.XInteractionRequest. On return the XInteractionSupplyName, if selected, will contain a new name supposed to resolve the name clash. The XInteractionReplaceExistingData will be selected if the clashing resource shall be overwritten.

    See Also:
        `API NameClashResolveRequest <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1ucb_1_1NameClashResolveRequest.html>`_
    """

    typeName: Literal['com.sun.star.ucb.NameClashResolveRequest']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ..., Classification: typing.Optional[InteractionClassification_6c4d10e7] = ..., TargetFolderURL: typing.Optional[str] = ..., ClashingName: typing.Optional[str] = ..., ProposedNewName: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            Classification (InteractionClassification, optional): Classification value.
            TargetFolderURL (str, optional): TargetFolderURL value.
            ClashingName (str, optional): ClashingName value.
            ProposedNewName (str, optional): ProposedNewName value.
        """
    @property
    def TargetFolderURL(self) -> str:
        """
        contains the URL of the folder that contains the clashing resource.
        """

    @property
    def ClashingName(self) -> str:
        """
        contains the clashing name.
        """

    @property
    def ProposedNewName(self) -> str:
        """
        contains a proposal for a new, non-clashing name.
        
        This field may be left empty if the implementation is not able to suggest a new name.
        """


__all__ = ['NameClashResolveRequest']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.script
from typing_extensions import Literal
from .x_library_container2 import XLibraryContainer2 as XLibraryContainer2_1c490e9f
from ..util.x_modifiable import XModifiable as XModifiable_a4f60b0a

class XPersistentLibraryContainer(XLibraryContainer2_1c490e9f, XModifiable_a4f60b0a):
    """
    describes a container of script libraries which is persistent.
    
    The type of persistence of the container elements is not defined here, but in derived interfaces or services using XPersistentLibraryContainer.
    
    The actual libraries are stored in some object - a sub folder, or a sub storage, for example - below the root location.
    
    **since**
    
        OOo 2.3

    See Also:
        `API XPersistentLibraryContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XPersistentLibraryContainer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.script.XPersistentLibraryContainer']

    def storeLibraries(self) -> None:
        """
        stores the libraries to the current location.

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    @property
    def ContainerLocationName(self) -> str:
        """
        denotes the name of the sub location where the container elements are actually stored.
        """

    @property
    def RootLocation(self) -> object:
        """
        denotes the root location associated with the container.
        
        The type of this location - it might be a folder in a file system, a storage, or anything else - is not specified here, but in derived interfaces or services implementing XPersistentLibraryContainer.
        
        All operations of the library container take place in a location below the root location, the so-called container location, whose name is exposed as ContainerLocationName.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.deployment
from .x_package_registry import XPackageRegistry as XPackageRegistry_3be50fa6

class PackageRegistryBackend(XPackageRegistry_3be50fa6):
    """
    Service Class

    The PackageRegistryBackend service is used to bind a specific type of XPackage which can be registered or revoked.
    
    All PackageRegistryBackend objects are related to a XPackageManager instance.
    
    **since**
    
        OOo 2.0

    See Also:
        `API PackageRegistryBackend <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1deployment_1_1PackageRegistryBackend.html>`_
    """
    def createPersistent(self, context: str, cacheDirectory: str, readOnly: bool) -> None:
        """
        Creates a persistent registry.
        """
    def createTransient(self, context: str) -> None:
        """
        Creates a transient registry.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.configuration
from .hierarchy_element import HierarchyElement as HierarchyElement_6fb410e9
from .x_template_instance import XTemplateInstance as XTemplateInstance_81181149
from ..lang.x_component import XComponent as XComponent_98dc0ab5

class SetElement(HierarchyElement_6fb410e9, XTemplateInstance_81181149, XComponent_98dc0ab5):
    """
    Service Class

    provides information about a dynamic element that can be inserted into a homogeneous set of elements within a hierarchy.
    
    Provides information about the element. Provides access to its containing set object. Allows controlling the lifetime of the element.
    
    Set elements may be added to and removed from the hierarchy at runtime. They bear user-defined names. They may exist independently, outside any container.
    
    New set element instances generally are created through members of com.sun.star.lang.XSingleServiceFactory or, if supported, com.sun.star.lang.XMultiServiceFactory on an implementation of SetUpdate. Initially, they are not contained in a set object and have no meaningful name.
    
    While an instance is not contained in a set object, it is owned by the client and can be disposed by calling com.sun.star.lang.XComponent.dispose(). The name of the object can freely be changed in that situation though without persistent effect.
    
    When the instance is inserted into a set (this includes replacing an existing element), ownership is transferred to the container. While it is contained in the container, clients must not dispose the object. When inserted, the name of the object is fixed and is used to identify it within the container. An implementation may support com.sun.star.container.XNamed.setName() even in this case. If it does, changing the name has the same effect of removing the object (under the old name) and then reinserting it into the same container (using the new name).
    
    When an instance is removed from a set (this includes being replaced by a new element), ownership is transferred to the client again. It can then be disposed or reinserted into a container. An instance can only be inserted into a container, if it was obtained from the same hierarchy.
    
    When a set element is removed from its set from outside the hierarchy, the container disposes of the object. This occurrence can be detected by registering a com.sun.star.lang.XEventListener with the object.
    
    If an implementation is part of a read-only view of the hierarchy, changing the name or parent is not supported (the object can't be removed from its container anyway).

    See Also:
        `API SetElement <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1SetElement.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class StringContext(object):
    """
    Struct Class

    Collection of string-related arguments used on all canvas text interfaces.
    
    A possibly much larger string than later rendered is necessary here, because in several languages, glyph selection is context dependent.
    
    **since**
    
        OOo 2.0

    See Also:
        `API StringContext <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1StringContext.html>`_
    """
    typeName: Literal['com.sun.star.rendering.StringContext']

    def __init__(self, Text: typing.Optional[str] = ..., StartPosition: typing.Optional[int] = ..., Length: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Text (str, optional): Text value.
            StartPosition (int, optional): StartPosition value.
            Length (int, optional): Length value.
        """


    @property
    def Text(self) -> str:
        """
        The complete text, from which a subset is selected by the parameters below.
        """


    @property
    def StartPosition(self) -> int:
        """
        Start position within the string.
        
        The first character has index 0.
        """


    @property
    def Length(self) -> int:
        """
        Length of the substring to actually use.
        
        Must be within the range [0,INTMAX].
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class InvalidateStyle(object):
    """
    Const

    specifies how to invalidate windows.

    See Also:
        `API InvalidateStyle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1InvalidateStyle.html>`_
    """
    CHILDREN: Literal[1]
    """
    The child windows are invalidated, too.
    """
    NOCHILDREN: Literal[2]
    """
    The child windows are not invalidated.
    """
    NOERASE: Literal[4]
    """
    The invalidated area is painted with the background color/pattern.
    """
    UPDATE: Literal[8]
    """
    The invalidated area is updated immediately.
    """
    TRANSPARENT: Literal[16]
    """
    The parent window is invalidated, too.
    """
    NOTRANSPARENT: Literal[32]
    """
    The parent window is not invalidated.
    """
    NOCLIPCHILDREN: Literal[16384]
    """
    The area is invalidated regardless of overlapping child windows.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class QRCode(object):
    """
    Struct Class

    This struct defines the attributes of a QR Code.
    
    **since**
    
        LibreOffice 6.4

    See Also:
        `API QRCode <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1QRCode.html>`_
    """
    typeName: Literal['com.sun.star.drawing.QRCode']

    def __init__(self, Payload: typing.Optional[str] = ..., ErrorCorrection: typing.Optional[int] = ..., Border: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Payload (str, optional): Payload value.
            ErrorCorrection (int, optional): ErrorCorrection value.
            Border (int, optional): Border value.
        """


    @property
    def Payload(self) -> str:
        """
        Text for which QR Code is made.
        """


    @property
    def ErrorCorrection(self) -> int:
        """
        Qr Code Error Correction Level.
        """


    @property
    def Border(self) -> int:
        """
        Border surrounding the Qr Code It is a non-negative value.
        
        One Border unit is equal to one dot in the generated QR code.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.registry
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
from .x_simple_registry import XSimpleRegistry as XSimpleRegistry_10150e9c

class NestedRegistry(XInitialization_d46c0cca, XSimpleRegistry_10150e9c):
    """
    Service Class

    supports a shared view on two different registries.
    
    The registry files will be opened in two different modes, registry1 will be opened with read/write rights and registry2 will be opened read-only. In the context of this service, the functions open, close, and destroy from XSimpleRegistry are not supported and throw an exception if they are used.
    
    Functions of XSimpleRegistry:
    
    Functions of XRegistryKey:
    
    How to initialize the registries:
    Use a sequence of XSimpleRegistry with two elements. The first element must be the registry which is opened with read/write rights and the second element must be the read-only one.
    Two different ways are possible:
    
    Guarantees:

    See Also:
        `API NestedRegistry <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1registry_1_1NestedRegistry.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.logging
from typing_extensions import Literal
import typing
from .x_log_formatter import XLogFormatter as XLogFormatter_e23d0d1d

class XCsvLogFormatter(XLogFormatter_e23d0d1d):
    """
    specifies the interface used for formatting log records for RFC4180 CSV output
    
    **since**
    
        OOo 3.0

    See Also:
        `API XCsvLogFormatter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1logging_1_1XCsvLogFormatter.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.logging.XCsvLogFormatter']

    def formatMultiColumn(self, columnData: 'typing.Tuple[str, ...]') -> str:
        """
        if the CsvLogFormatter is set to have more than one column, any logged information has to be send through this method before calling log().
        
        E.g.:
        
        XLoggerInstance.log(1000, XCsvLogFormatterInstance.formatMultiColumn(columnData))
        """
    @property
    def Columnnames(self) -> 'typing.Tuple[str, ...]':
        """
        Defines the names of the additional columns this defaults to only one row titled \"message\".
        
        if this is set to more than one column, the messages need to be preformatted using formatMultiColumn
        """

    @property
    def LogEventNo(self) -> bool:
        """
        Defines if the EventNo should be logged.
        """

    @property
    def LogSource(self) -> bool:
        """
        Defines if the Source should be logged.
        """

    @property
    def LogThread(self) -> bool:
        """
        Defines if the ThreadId should be logged.
        """

    @property
    def LogTimestamp(self) -> bool:
        """
        Defines if the Timestamp should be logged.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.bridge.oleautomation
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class Date(object):
    """
    Struct Class

    is the UNO representation of the Automation type DATE.
    
    A DATE could actually be represented as double in UNO and therefore a typedef from double to a date type would do. But a typedef cannot be expressed in all language bindings. In the case where no typedefs are supported the actual type is used. That is, a typedef'd date type would be represented as double in Java. The information that the double is a date type is lost.
    
    When calling Automation objects from UNO the distinction between double and date type is important. Therefore Date is declared as struct.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API Date <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1Date.html>`_
    """
    typeName: Literal['com.sun.star.bridge.oleautomation.Date']

    def __init__(self, Value: typing.Optional[float] = ...) -> None:
        """
        Constructor

        Arguments:
            Value (float, optional): Value value.
        """


    @property
    def Value(self) -> float:
        """
        corresponds to the Automation type DATE.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.container
from typing_extensions import Literal
import typing
from .x_element_access import XElementAccess as XElementAccess_cd60e3f

class XIdentifierAccess(XElementAccess_cd60e3f):
    """
    provides access to the elements of a collection through a unique identifier.

    See Also:
        `API XIdentifierAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1container_1_1XIdentifierAccess.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.container.XIdentifierAccess']

    def getByIdentifier(self, Identifier: int) -> object:
        """

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def getIdentifiers(self) -> 'typing.Tuple[int, ...]':
        """
        The order of the identifiers is not specified.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class FontUnderline(object):
    """
    Const

    These values are used to specify the kind of underlining.
    
    They may be expanded in future versions.

    See Also:
        `API FontUnderline <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FontUnderline.html>`_
    """
    NONE: Literal[0]
    """
    specifies no underlining.
    """
    SINGLE: Literal[1]
    """
    specifies underlining with a single line.
    """
    DOUBLE: Literal[2]
    """
    specifies underlining with a double line.
    """
    DOTTED: Literal[3]
    """
    specifies underlining with a dotted line.
    """
    DONTKNOW: Literal[4]
    """
    The kind of underlining is not known.
    """
    DASH: Literal[5]
    """
    specifies underlining with a dashed line.
    """
    LONGDASH: Literal[6]
    """
    specifies underlining with long dashes.
    """
    DASHDOT: Literal[7]
    """
    specifies underlining with a dash and dot sequence.
    """
    DASHDOTDOT: Literal[8]
    """
    specifies underlining with a dash, dot, dot sequence.
    """
    SMALLWAVE: Literal[9]
    """
    specifies underlining with a small wave.
    """
    WAVE: Literal[10]
    """
    specifies underlining with a wave.
    """
    DOUBLEWAVE: Literal[11]
    """
    specifies underlining with a double wave.
    """
    BOLD: Literal[12]
    """
    specifies underlining with a bold line.
    """
    BOLDDOTTED: Literal[13]
    """
    specifies underlining with bold dots.
    """
    BOLDDASH: Literal[14]
    """
    specifies underlining with bold dashes.
    """
    BOLDLONGDASH: Literal[15]
    """
    specifies underlining with long bold dashes.
    """
    BOLDDASHDOT: Literal[16]
    """
    specifies underlining with a dash and dot sequence in bold.
    """
    BOLDDASHDOTDOT: Literal[17]
    """
    specifies underlining with a dash, dot, dot sequence in bold.
    """
    BOLDWAVE: Literal[18]
    """
    specifies underlining with a bold wave.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..beans.property import Property as Property_8f4e0a76
from .search_info import SearchInfo as SearchInfo_8daf0a24


class SearchCommandArgument(object):
    """
    Struct Class

    The argument for the command \"search\".

    See Also:
        `API SearchCommandArgument <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1SearchCommandArgument.html>`_
    """
    typeName: Literal['com.sun.star.ucb.SearchCommandArgument']

    def __init__(self, Properties: typing.Optional[typing.Tuple[Property_8f4e0a76, ...]] = ..., Info: typing.Optional[SearchInfo_8daf0a24] = ...) -> None:
        """
        Constructor

        Arguments:
            Properties (typing.Tuple[Property, ...], optional): Properties value.
            Info (SearchInfo, optional): Info value.
        """


    @property
    def Properties(self) -> typing.Tuple[Property_8f4e0a76, ...]:
        """
        the properties for which values shall be provided through the ContentResultSet returned by the search command.
        """


    @property
    def Info(self) -> SearchInfo_8daf0a24:
        """
        the search criteria.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API WrapTextMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0ae>`_
"""

DYNAMIC: 'uno.Enum'
"""
text flow depends on the situation.

The text formatting decides the best way.
"""
LEFT: 'uno.Enum'
"""
the object is left adjusted.

text flows to the left side of the object.

adjusted to the left.
"""
NONE: 'uno.Enum'
"""
text does not flow around the object.
"""
PARALLEL: 'uno.Enum'
"""
text flows to the left and right of the object.
"""
RIGHT: 'uno.Enum'
"""
the object is right adjusted.

text flows to the right side of the object.

adjusted to the right.
"""
THROUGH: 'uno.Enum'
"""
text flow ignores the object.
"""
THROUGHT: 'uno.Enum'
"""
text flow ignores the object: errant spelling deprecated in version 5.4
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.animations
from typing_extensions import Literal
"""
Const


See Also:
    `API TransitionSubType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html>`_
"""
DEFAULT: Literal[0]
LEFTTORIGHT: Literal[1]
TOPTOBOTTOM: Literal[2]
TOPLEFT: Literal[3]
TOPRIGHT: Literal[4]
BOTTOMRIGHT: Literal[5]
BOTTOMLEFT: Literal[6]
TOPCENTER: Literal[7]
RIGHTCENTER: Literal[8]
BOTTOMCENTER: Literal[9]
LEFTCENTER: Literal[10]
CORNERSIN: Literal[11]
CORNERSOUT: Literal[12]
VERTICAL: Literal[13]
HORIZONTAL: Literal[14]
DIAGONALBOTTOMLEFT: Literal[15]
DIAGONALTOPLEFT: Literal[16]
DOUBLEBARNDOOR: Literal[17]
DOUBLEDIAMOND: Literal[18]
DOWN: Literal[19]
LEFT: Literal[20]
UP: Literal[21]
RIGHT: Literal[22]
RECTANGLE: Literal[25]
DIAMOND: Literal[26]
CIRCLE: Literal[27]
FOURPOINT: Literal[28]
FIVEPOINT: Literal[29]
SIXPOINT: Literal[30]
HEART: Literal[31]
KEYHOLE: Literal[32]
CLOCKWISETWELVE: Literal[33]
CLOCKWISETHREE: Literal[34]
CLOCKWISESIX: Literal[35]
CLOCKWISENINE: Literal[36]
TWOBLADEVERTICAL: Literal[37]
TWOBLADEHORIZONTAL: Literal[38]
FOURBLADE: Literal[39]
CLOCKWISETOP: Literal[40]
CLOCKWISERIGHT: Literal[41]
CLOCKWISEBOTTOM: Literal[42]
CLOCKWISELEFT: Literal[43]
CLOCKWISETOPLEFT: Literal[44]
COUNTERCLOCKWISEBOTTOMLEFT: Literal[45]
CLOCKWISEBOTTOMRIGHT: Literal[46]
COUNTERCLOCKWISETOPRIGHT: Literal[47]
CENTERTOP: Literal[48]
CENTERRIGHT: Literal[49]
TOP: Literal[50]
BOTTOM: Literal[52]
FANOUTVERTICAL: Literal[54]
FANOUTHORIZONTAL: Literal[55]
FANINVERTICAL: Literal[56]
FANINHORIZONTAL: Literal[57]
PARALLELVERTICAL: Literal[58]
PARALLELDIAGONAL: Literal[59]
OPPOSITEVERTICAL: Literal[60]
OPPOSITEHORIZONTAL: Literal[61]
PARALLELDIAGONALTOPLEFT: Literal[62]
PARALLELDIAGONALBOTTOMLEFT: Literal[63]
TOPLEFTHORIZONTAL: Literal[64]
TOPLEFTDIAGONAL: Literal[65]
TOPRIGHTDIAGONAL: Literal[66]
BOTTOMRIGHTDIAGONAL: Literal[67]
BOTTOMLEFTDIAGONAL: Literal[68]
TOPLEFTCLOCKWISE: Literal[69]
TOPRIGHTCLOCKWISE: Literal[70]
BOTTOMRIGHTCLOCKWISE: Literal[71]
BOTTOMLEFTCLOCKWISE: Literal[72]
TOPLEFTCOUNTERCLOCKWISE: Literal[73]
TOPRIGHTCOUNTERCLOCKWISE: Literal[74]
BOTTOMRIGHTCOUNTERCLOCKWISE: Literal[75]
BOTTOMLEFTCOUNTERCLOCKWISE: Literal[76]
VERTICALTOPSAME: Literal[77]
VERTICALBOTTOMSAME: Literal[78]
VERTICALTOPLEFTOPPOSITE: Literal[79]
VERTICALBOTTOMLEFTOPPOSITE: Literal[80]
HORIZONTALLEFTSAME: Literal[81]
HORIZONTALRIGHTSAME: Literal[82]
HORIZONTALTOPLEFTOPPOSITE: Literal[83]
HORIZONTALTOPRIGHTOPPOSITE: Literal[84]
DIAGONALBOTTOMLEFTOPPOSITE: Literal[85]
DIAGONALTOPLEFTOPPOSITE: Literal[86]
TWOBOXTOP: Literal[87]
TWOBOXBOTTOM: Literal[88]
TWOBOXLEFT: Literal[89]
TWOBOXRIGHT: Literal[90]
FOURBOXVERTICAL: Literal[91]
FOURBOXHORIZONTAL: Literal[92]
VERTICALLEFT: Literal[93]
VERTICALRIGHT: Literal[94]
HORIZONTALLEFT: Literal[95]
HORIZONTALRIGHT: Literal[96]
FROMLEFT: Literal[97]
FROMTOP: Literal[98]
FROMRIGHT: Literal[99]
FROMBOTTOM: Literal[100]
CROSSFADE: Literal[101]
FADETOCOLOR: Literal[102]
FADEFROMCOLOR: Literal[103]
FADEOVERCOLOR: Literal[104]
THREEBLADE: Literal[105]
EIGHTBLADE: Literal[106]
ONEBLADE: Literal[107]
ACROSS: Literal[108]
TOPLEFTVERTICAL: Literal[109]
COMBHORIZONTAL: Literal[110]
COMBVERTICAL: Literal[111]
IN: Literal[112]
OUT: Literal[113]
ROTATEIN: Literal[114]
ROTATEOUT: Literal[115]
FROMTOPLEFT: Literal[116]
FROMTOPRIGHT: Literal[117]
FROMBOTTOMLEFT: Literal[118]
FROMBOTTOMRIGHT: Literal[119]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_sheet_filter_descriptor import XSheetFilterDescriptor as XSheetFilterDescriptor_47cc0ff7
    from .x_sub_total_descriptor import XSubTotalDescriptor as XSubTotalDescriptor_19fd0ec6
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class XDatabaseRange(XInterface_8f010a43):
    """
    provides access to the settings and options of a database range.

    See Also:
        `API XDatabaseRange <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XDatabaseRange.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XDatabaseRange']

    def getDataArea(self) -> 'CellRangeAddress_ec450d43':
        """
        returns the data area of the database range in the spreadsheet document.
        """
    def getFilterDescriptor(self) -> 'XSheetFilterDescriptor_47cc0ff7':
        """
        returns the filter descriptor stored with the database range.
        
        If the filter descriptor is modified, the new filtering is carried out when XDatabaseRange.refresh() is called.
        """
    def getImportDescriptor(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        returns the database import descriptor stored with this database range.
        """
    def getSortDescriptor(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        returns the sort descriptor stored with the database range.
        """
    def getSubTotalDescriptor(self) -> 'XSubTotalDescriptor_19fd0ec6':
        """
        returns the subtotal descriptor stored with the database range.
        
        If the subtotal descriptor is modified, the new subtotals are inserted when XDatabaseRange.refresh() is called.
        """
    def refresh(self) -> None:
        """
        executes the stored import, filter, sorting, and subtotals descriptors again.
        """
    def setDataArea(self, aDataArea: 'CellRangeAddress_ec450d43') -> None:
        """
        sets the data area of the database range.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.inspection
from typing_extensions import Literal
import typing
from .x_property_control import XPropertyControl as XPropertyControl_3f260fe2
if typing.TYPE_CHECKING:
    from ..awt.x_action_listener import XActionListener as XActionListener_c7560c50

class XHyperlinkControl(XPropertyControl_3f260fe2):
    """
    defines the interface for an XPropertyControl which displays its value in a hyperlink-like way
    
    Hyperlink controls exchange their value (XPropertyControl.Value) as strings.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API XHyperlinkControl <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1inspection_1_1XHyperlinkControl.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.inspection.XHyperlinkControl']

    def addActionListener(self, listener: 'XActionListener_c7560c50') -> None:
        """
        adds a listener which will be notified when the user clicked the hyperlink text in the control
        """
    def removeActionListener(self, listener: 'XActionListener_c7560c50') -> None:
        """
        removes a listener which was previously added via addActionListener()
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ui
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class LayoutSize(object):
    """
    Struct Class

    Size used for layouting windows.
    
    It specifies a range of valid values and a preferred value. The values must not violate the relation 0 â¤ Minimum â¤ Preferred â¤ Maximum.

    See Also:
        `API LayoutSize <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ui_1_1LayoutSize.html>`_
    """
    typeName: Literal['com.sun.star.ui.LayoutSize']

    def __init__(self, Minimum: typing.Optional[int] = ..., Maximum: typing.Optional[int] = ..., Preferred: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Minimum (int, optional): Minimum value.
            Maximum (int, optional): Maximum value.
            Preferred (int, optional): Preferred value.
        """


    @property
    def Minimum(self) -> int:
        ...


    @property
    def Maximum(self) -> int:
        ...


    @property
    def Preferred(self) -> int:
        ...





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdbc
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
    from .x_result_set import XResultSet as XResultSet_98e30aa7

class XArray(XInterface_8f010a43):
    """
    is used for mapping the SQL type com.sun.star.sdbc.DataType.ARRAY.
    
    By default, an Array is a transaction duration reference to an SQL array. By default, an Array is implemented using a SQL LOCATOR(array) internally.

    See Also:
        `API XArray <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdbc.XArray']

    def getArray(self, typeMap: 'XNameAccess_e2ab0cf6') -> 'typing.Tuple[object, ...]':
        """
        retrieves the contents of the SQL array designated by this Array object, using the specified typeMap for type map customizations.
        
        If the base type of the array does not match a user-defined type in typeMap , the standard mapping is used instead.

        Raises:
            SQLException: ``SQLException``
        """
    def getArrayAtIndex(self, index: int, count: int, typeMap: 'XNameAccess_e2ab0cf6') -> 'typing.Tuple[object, ...]':
        """
        returns an array containing a slice of the SQL array, beginning with the specified index and containing up to count successive elements of the SQL array.

        Raises:
            SQLException: ``SQLException``
        """
    def getBaseType(self) -> int:
        """
        returns the SDBC type of the elements in the array designated by this Array object.

        Raises:
            SQLException: ``SQLException``
        """
    def getBaseTypeName(self) -> str:
        """
        returns the SQL type name of the elements in the array designated by this Array object.
        
        If the elements are a built-in type, it returns the database-specific type name of the elements. If the elements are a user-defined type (UDT), this method returns the fully-qualified SQL type name.

        Raises:
            SQLException: ``SQLException``
        """
    def getResultSet(self, typeMap: 'XNameAccess_e2ab0cf6') -> 'XResultSet_98e30aa7':
        """
        returns a result set that contains the elements of the array designated by this Array object and uses the given typeMap to map the array elements.
        
        If the base type of the array does not match a user-defined type in typeMap or the typeMap is NULL , the connection type mapping is used instead.
        
        The result set contains one row for each array element, with two columns in each row. The second column stores the element value; the first column stores the index into the array for that element (with the first array element being at index 1). The rows are in ascending order corresponding to the order of the indices.

        Raises:
            SQLException: ``SQLException``
        """
    def getResultSetAtIndex(self, index: int, count: int, typeMap: 'XNameAccess_e2ab0cf6') -> 'XResultSet_98e30aa7':
        """
        returns a result set holding the elements of the subarray that starts at index index and contains up to count successive elements.
        
        This method uses the given typeMap to map the array elements. If the base type of the array does not match a user-defined type in typeMap or the typeMap is NULL , the connection type mapping is used instead.
        
        The result set contains one row for each array element, with two columns in each row. The second column stores the element value; the first column stores the index into the array for that element (with the first array element being at index 1). The rows are in ascending order corresponding to the order of the indices.

        Raises:
            SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing_extensions import Literal
from .global_transfer_command_argument import GlobalTransferCommandArgument as GlobalTransferCommandArgument_9ae711da
from .transfer_command_operation import TransferCommandOperation as TransferCommandOperation_486a0ff7
import typing


class GlobalTransferCommandArgument2(GlobalTransferCommandArgument_9ae711da):
    """
    Struct Class

    This struct extends the one for transfers arguments by adding a Mime type and a Document Id property to it.

    See Also:
        `API GlobalTransferCommandArgument2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1GlobalTransferCommandArgument2.html>`_
    """
    typeName: Literal['com.sun.star.ucb.GlobalTransferCommandArgument2']

    def __init__(self, Operation: typing.Optional[TransferCommandOperation_486a0ff7] = ..., SourceURL: typing.Optional[str] = ..., TargetURL: typing.Optional[str] = ..., NewTitle: typing.Optional[str] = ..., NameClash: typing.Optional[int] = ..., MimeType: typing.Optional[str] = ..., DocumentId: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Operation (TransferCommandOperation, optional): Operation value.
            SourceURL (str, optional): SourceURL value.
            TargetURL (str, optional): TargetURL value.
            NewTitle (str, optional): NewTitle value.
            NameClash (int, optional): NameClash value.
            MimeType (str, optional): MimeType value.
            DocumentId (str, optional): DocumentId value.
        """


    @property
    def MimeType(self) -> str:
        """
        contains the MIME type of the source object.
        """


    @property
    def DocumentId(self) -> str:
        """
        contains the DocumentId of the source object.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing
from typing_extensions import Literal
from .x_shape import XShape as XShape_8fd00a3d

class XShapeGroup(XShape_8fd00a3d):
    """
    is implemented by Shapes that contain other Shapes.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XShapeGroup <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeGroup.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.drawing.XShapeGroup']

    def enterGroup(self) -> None:
        """
        enters the group which enables the editing function for the parts of a grouped Shape.
        
        Then the parts can be edited instead of the group as a whole.
        
        This affects only the user interface. The behavior is not specified if this instance is not visible on any view. In this case it may or may not work.
        """
    def leaveGroup(self) -> None:
        """
        leaves the group, which disables the editing function for the parts of a grouped Shape.
        
        Then only the group as a whole can be edited.
        
        This affects only the user interface. The behavior is not specified if this instance is not visible on any view. In this case it may or may not work.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.animations
from typing_extensions import Literal
"""
Const

This constants defines a type for an animation node.

It can be used to quickly identify semantic blocks inside an animation hierarchy.

**since**

    LibreOffice 7.1

See Also:
    `API AnimationNodeType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1AnimationNodeType.html>`_
"""
CUSTOM: Literal[0]
"""
Defines a custom time node.
"""
PAR: Literal[1]
"""
Defines a parallel time container.
"""
SEQ: Literal[2]
"""
Defines a sequence time container.
"""
ITERATE: Literal[3]
"""
Defines an iterate time container.
"""
ANIMATE: Literal[4]
"""
Defines a generic attribute animation.
"""
SET: Literal[5]
"""
Defines a simple mean of just setting the value of an attribute for a specified duration.
"""
ANIMATEMOTION: Literal[6]
"""
Defines a move animation along a path.
"""
ANIMATECOLOR: Literal[7]
"""
Defines an animation of a color attribute.
"""
ANIMATETRANSFORM: Literal[8]
"""
Defines an animation of a transformation attribute.
"""
TRANSITIONFILTER: Literal[9]
"""
Defines an animation of a filter behavior.
"""
AUDIO: Literal[10]
"""
Defines an audio effect.
"""
COMMAND: Literal[11]
"""
Defines a command effect.
"""
ANIMATEPHYSICS: Literal[12]
"""
Defines a physics animation.

**since**

    LibreOffice 7.1
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.i18n.boundary import Boundary as Boundary
from .._pyi.i18n.break_iterator import BreakIterator as BreakIterator
from .._pyi.i18n.calendar import Calendar as Calendar
from .._pyi.i18n.calendar2 import Calendar2 as Calendar2
from .._pyi.i18n.calendar_item import CalendarItem as CalendarItem
from .._pyi.i18n.calendar_item2 import CalendarItem2 as CalendarItem2
from .._pyi.i18n.chapter_collator import ChapterCollator as ChapterCollator
from .._pyi.i18n.character_classification import CharacterClassification as CharacterClassification
from .._pyi.i18n.collator import Collator as Collator
from .._pyi.i18n.currency import Currency as Currency
from .._pyi.i18n.currency2 import Currency2 as Currency2
from .._pyi.i18n.forbidden_characters import ForbiddenCharacters as ForbiddenCharacters
from .._pyi.i18n.format_element import FormatElement as FormatElement
from .._pyi.i18n.implementation import Implementation as Implementation
from .._pyi.i18n.index_entry_supplier import IndexEntrySupplier as IndexEntrySupplier
from .._pyi.i18n.input_sequence_checker import InputSequenceChecker as InputSequenceChecker
from .._pyi.i18n.language_country_info import LanguageCountryInfo as LanguageCountryInfo
from .._pyi.i18n.line_break_hyphenation_options import LineBreakHyphenationOptions as LineBreakHyphenationOptions
from .._pyi.i18n.line_break_results import LineBreakResults as LineBreakResults
from .._pyi.i18n.line_break_user_options import LineBreakUserOptions as LineBreakUserOptions
from .._pyi.i18n.locale_calendar import LocaleCalendar as LocaleCalendar
from .._pyi.i18n.locale_calendar2 import LocaleCalendar2 as LocaleCalendar2
from .._pyi.i18n.locale_data import LocaleData as LocaleData
from .._pyi.i18n.locale_data2 import LocaleData2 as LocaleData2
from .._pyi.i18n.locale_data_item import LocaleDataItem as LocaleDataItem
from .._pyi.i18n.locale_data_item2 import LocaleDataItem2 as LocaleDataItem2
from .._pyi.i18n.multiple_chars_output_exception import MultipleCharsOutputException as MultipleCharsOutputException
from .._pyi.i18n.native_number_supplier import NativeNumberSupplier as NativeNumberSupplier
from .._pyi.i18n.native_number_supplier2 import NativeNumberSupplier2 as NativeNumberSupplier2
from .._pyi.i18n.native_number_xml_attributes import NativeNumberXmlAttributes as NativeNumberXmlAttributes
from .._pyi.i18n.native_number_xml_attributes2 import NativeNumberXmlAttributes2 as NativeNumberXmlAttributes2
from .._pyi.i18n.number_format_code import NumberFormatCode as NumberFormatCode
from .._pyi.i18n.number_format_mapper import NumberFormatMapper as NumberFormatMapper
from .._pyi.i18n.ordinal_suffix import OrdinalSuffix as OrdinalSuffix
from .._pyi.i18n.parse_result import ParseResult as ParseResult
from .._pyi.i18n.text_conversion import TextConversion as TextConversion
from .._pyi.i18n.text_conversion_result import TextConversionResult as TextConversionResult
from .._pyi.i18n.transliteration import Transliteration as Transliteration
from .._pyi.i18n.x_break_iterator import XBreakIterator as XBreakIterator
from .._pyi.i18n.x_calendar import XCalendar as XCalendar
from .._pyi.i18n.x_calendar3 import XCalendar3 as XCalendar3
from .._pyi.i18n.x_calendar4 import XCalendar4 as XCalendar4
from .._pyi.i18n.x_character_classification import XCharacterClassification as XCharacterClassification
from .._pyi.i18n.x_collator import XCollator as XCollator
from .._pyi.i18n.x_extended_calendar import XExtendedCalendar as XExtendedCalendar
from .._pyi.i18n.x_extended_index_entry_supplier import XExtendedIndexEntrySupplier as XExtendedIndexEntrySupplier
from .._pyi.i18n.x_extended_input_sequence_checker import XExtendedInputSequenceChecker as XExtendedInputSequenceChecker
from .._pyi.i18n.x_extended_text_conversion import XExtendedTextConversion as XExtendedTextConversion
from .._pyi.i18n.x_extended_transliteration import XExtendedTransliteration as XExtendedTransliteration
from .._pyi.i18n.x_forbidden_characters import XForbiddenCharacters as XForbiddenCharacters
from .._pyi.i18n.x_index_entry_supplier import XIndexEntrySupplier as XIndexEntrySupplier
from .._pyi.i18n.x_input_sequence_checker import XInputSequenceChecker as XInputSequenceChecker
from .._pyi.i18n.x_locale_data import XLocaleData as XLocaleData
from .._pyi.i18n.x_locale_data2 import XLocaleData2 as XLocaleData2
from .._pyi.i18n.x_locale_data3 import XLocaleData3 as XLocaleData3
from .._pyi.i18n.x_locale_data4 import XLocaleData4 as XLocaleData4
from .._pyi.i18n.x_locale_data5 import XLocaleData5 as XLocaleData5
from .._pyi.i18n.x_native_number_supplier import XNativeNumberSupplier as XNativeNumberSupplier
from .._pyi.i18n.x_native_number_supplier2 import XNativeNumberSupplier2 as XNativeNumberSupplier2
from .._pyi.i18n.x_number_format_code import XNumberFormatCode as XNumberFormatCode
from .._pyi.i18n.x_ordinal_suffix import XOrdinalSuffix as XOrdinalSuffix
from .._pyi.i18n.x_script_type_detector import XScriptTypeDetector as XScriptTypeDetector
from .._pyi.i18n.x_text_conversion import XTextConversion as XTextConversion
from .._pyi.i18n.x_transliteration import XTransliteration as XTransliteration



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.document
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from ..io.x_output_stream import XOutputStream as XOutputStream_a4e00b35

class XBinaryStreamResolver(XInterface_8f010a43):
    """
    This interface encapsulates functionality to get/resolve binary data streams. It is used to transform binary data to a URL or to transform a URL to binary data. The binary data is represented through input and output streams.
    
    In the case of transforming a URL to binary data, the getInputStream method is used. This returns a com.sun.star.io.XInputStream from which the binary data, transformed from the given URL, can be read.
    
    In the case of transforming binary data to a URL, a com.sun.star.io.XOutputStream is created first to write the binary data to. After this, the resolveOutputStream method can be used to transform the binary data, represented through the com.sun.star.io.XOutputStream interface, to a URL.

    See Also:
        `API XBinaryStreamResolver <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XBinaryStreamResolver.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.document.XBinaryStreamResolver']

    def createOutputStream(self) -> 'XOutputStream_a4e00b35':
        """
        creates an output stream, to which binary data can be written.
        
        After writing, a URL can be retrieved by a call to XBinaryStreamResolver.resolveOutputStream().
        """
    def getInputStream(self, aURL: str) -> 'XInputStream_98d40ab4':
        """
        converts the given URL from the source URL namespace to an input stream, from which binary data can be read
        """
    def resolveOutputStream(self, aBinaryStream: 'XOutputStream_a4e00b35') -> str:
        """
        converts the output stream, data has been written to, to a URL in source URL namespace.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.configuration
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XTemplateContainer(XInterface_8f010a43):
    """
    is implemented by objects that contain instances of a named template to provide information about the template.
    
    An implementation will also implement com.sun.star.lang.XSingleServiceFactory, in which case that interface creates instances of the specified template.
    
    If multiple templates are supported, the supported factory interface may be com.sun.star.lang.XMultiServiceFactory, in which case the string returned from XTemplateContainer.getElementTemplateName() can be used as the service name argument.

    See Also:
        `API XTemplateContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1XTemplateContainer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.configuration.XTemplateContainer']

    def getElementTemplateName(self) -> str:
        """
        retrieves the name of the template
        
        If instances of multiple templates are accepted by the container, this is the name of the basic or primary template.
        
        Instances of the template must be created using an appropriate factory.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.presentation
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XPresentation(XInterface_8f010a43):
    """
    With this interface you can control any object that implements a Presentation.

    See Also:
        `API XPresentation <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1presentation_1_1XPresentation.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.presentation.XPresentation']

    def end(self) -> None:
        """
        The presentation is stopped and the full-screen mode will end.
        """
    def rehearseTimings(self) -> None:
        """
        Starts the presentation from the beginning and shows the actual running time to the user.
        """
    def start(self) -> None:
        """
        The presentation is shown in full-screen and started from the beginning.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt.tree
from typing_extensions import Literal
import typing
from ...view.x_multi_selection_supplier import XMultiSelectionSupplier as XMultiSelectionSupplier_4b0d1020
if typing.TYPE_CHECKING:
    from ..rectangle import Rectangle as Rectangle_84b109e9
    from .x_tree_edit_listener import XTreeEditListener as XTreeEditListener_25e10ee6
    from .x_tree_expansion_listener import XTreeExpansionListener as XTreeExpansionListener_78511115
    from .x_tree_node import XTreeNode as XTreeNode_baaf0ba0

class XTreeControl(XMultiSelectionSupplier_4b0d1020):
    """
    An interface to a control that displays a set of hierarchical data as an outline.

    See Also:
        `API XTreeControl <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeControl.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.tree.XTreeControl']

    def addTreeEditListener(self, Listener: 'XTreeEditListener_25e10ee6') -> None:
        """
        Adds a XTreeEditListener.
        """
    def addTreeExpansionListener(self, Listener: 'XTreeExpansionListener_78511115') -> None:
        """
        Adds a listener for TreeExpansion events.
        """
    def cancelEditing(self) -> None:
        """
        Cancels the current editing session.
        
        Has no effect if the tree isn't being edited.
        """
    def collapseNode(self, Node: 'XTreeNode_baaf0ba0') -> None:
        """
        Ensures that Node is collapsed.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            ExpandVetoException: ``ExpandVetoException``
        """
    def expandNode(self, Node: 'XTreeNode_baaf0ba0') -> None:
        """
        Ensures that Node is expanded and visible.
        
        If Node is a leaf node, this will have no effect.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            ExpandVetoException: ``ExpandVetoException``
        """
    def getClosestNodeForLocation(self, x: int, y: int) -> 'XTreeNode_baaf0ba0':
        """
        Returns the node that is closest to x,y.
        
        If no nodes are currently viewable, or there is no model, returns null, otherwise it always returns a valid node. To test if the node is exactly at x, y, use getNodeForLocation().
        """
    def getNodeForLocation(self, x: int, y: int) -> 'XTreeNode_baaf0ba0':
        """
        Returns the node at the specified location.
        """
    def getNodeRect(self, Node: 'XTreeNode_baaf0ba0') -> 'Rectangle_84b109e9':
        """
        returns the rectangle occupied by the visual representation of the given node

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def isEditing(self) -> bool:
        """
        Returns TRUE if one of tree's nodes is being currently edited.
        
        The node that is being edited can be obtained using com.sun.star.view.XSelectionSupplier.getSelection().
        """
    def isNodeCollapsed(self, Node: 'XTreeNode_baaf0ba0') -> bool:
        """
        Returns TRUE if Node is currently collapsed.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def isNodeExpanded(self, Node: 'XTreeNode_baaf0ba0') -> bool:
        """
        Returns TRUE if Node is currently expanded.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def isNodeVisible(self, Node: 'XTreeNode_baaf0ba0') -> bool:
        """
        Returns TRUE if Node is currently visible.
        
        Visible means it is either the root or all of its parents are expanded.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def makeNodeVisible(self, Node: 'XTreeNode_baaf0ba0') -> None:
        """
        Ensures that Node is currently visible.
        
        This includes expanding all parent nodes and scroll the control so this node is visible in the controls display area.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            ExpandVetoException: ``ExpandVetoException``
        """
    def removeTreeEditListener(self, Listener: 'XTreeEditListener_25e10ee6') -> None:
        """
        Removes a XTreeEditListener.
        """
    def removeTreeExpansionListener(self, Listener: 'XTreeExpansionListener_78511115') -> None:
        """
        Removes a listener for TreeExpansion events.
        """
    def startEditingAtNode(self, Node: 'XTreeNode_baaf0ba0') -> None:
        """
        Selects Node and initiates editing.
        
        If TreeControlModel.Editable is FALSE or if there are no registered XTreeEditListener, this call has no effect.
        
        Calling this method also ensures that Node will become visible.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def stopEditing(self) -> bool:
        """
        Ends the current editing session.
        
        All registered XTreeEditListener are notified if an editing session was in progress
        
        Has no effect if the tree isn't being edited.
        """
    @property
    def DefaultCollapsedGraphicURL(self) -> str:
        """
        If the given URL points to a loadable graphic, the graphic is rendered before collapsed non leaf nodes.
        
        This can be overridden for individual nodes by XTreeNode.getCollapsedGraphicURL()
        """

    @property
    def DefaultExpandedGraphicURL(self) -> str:
        """
        If the given URL points to a loadable graphic, the graphic is rendered before expanded non leaf nodes.
        
        This can be overridden for individual nodes by XTreeNode.getExpandedGraphicURL()
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from ..sdb.row_change_event import RowChangeEvent as RowChangeEvent_ba0c0bc1

class XConfirmDeleteListener(XEventListener_c7230c4a):
    """
    allows to register a component for confirming deletions of rows in a com.sun.star.form.component.DataForm.

    See Also:
        `API XConfirmDeleteListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XConfirmDeleteListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.form.XConfirmDeleteListener']

    def confirmDelete(self, aEvent: 'RowChangeEvent_ba0c0bc1') -> bool:
        """
        is invoked when the current record of a database form will be deleted.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.chart2.data
from typing_extensions import Literal
import typing
from ...beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_data_provider import XDataProvider as XDataProvider_122f0e31
from .x_range_xml_conversion import XRangeXMLConversion as XRangeXMLConversion_6cef1070
from ...lang.x_component import XComponent as XComponent_98dc0ab5
from ...lang.x_initialization import XInitialization as XInitialization_d46c0cca
from ...sdbc.x_parameters import XParameters as XParameters_a36c0b10
from ...sdbc.x_row_set import XRowSet as XRowSet_7a090960
if typing.TYPE_CHECKING:
    from ...sdbc.x_connection import XConnection as XConnection_a36a0b0c

class XDatabaseDataProvider(XPropertySet_bc180bfa, XDataProvider_122f0e31, XRangeXMLConversion_6cef1070, XComponent_98dc0ab5, XInitialization_d46c0cca, XParameters_a36c0b10, XRowSet_7a090960):
    """
    identifies a XDataProvider for result sets.

    See Also:
        `API XDatabaseDataProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1data_1_1XDatabaseDataProvider.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart2.data.XDatabaseDataProvider']

    @property
    def DetailFields(self) -> 'typing.Tuple[str, ...]':
        """
        is used for subreports and contains the names of the columns of the subreport which are related to the master fields of the parent report.
        
        Entries in this sequence can either denote column names in the sub report, or parameter names.
        For instance, you could base the report on the SQL statement SELECT * FROM invoices WHERE cust_ref = :cid, and add cid to the DetailFields property. In this case, the parameter will be filled from the corresponding master field.
        Alternatively, you could simply base your report on the table invoices, and add the column name cust_ref to the DetailFields. In this case, and implicit filter clause WHERE cust_ref = :<new_param_name> will be created, and the artificial parameter will be filled from the corresponding master field.
        If a string in this property denotes both a column name and a parameter name, it is undefined which way it is interpreted, but implementations of the service are required to either decide for the parameter or the column, and proceed as usual.
        
        The columns specified herein typically represent a part of the primary key fields or their aliases of the detail report.
        
        If the report is no sub report (e.g. its parent is not a report itself), this property is not evaluated.
        """

    @property
    def MasterFields(self) -> 'typing.Tuple[str, ...]':
        """
        is used for subreports and contains the names of columns of the parent report.
        
        These columns are typically the foreign key fields of the parent report. The values of these columns are used to identify the data for the subreport. Each time the parent report changes its current row, the subreport requeries it's data based on the values of the master fields.
        
        If the report is no sub report (e.g. its parent is not a report itself), this property is not evaluated.
        """

    @property
    def ActiveConnection(self) -> 'XConnection_a36a0b0c':
        """
        specifies the active connection which is used to create the resulting report.
        """

    @property
    def ApplyFilter(self) -> bool:
        """
        indicates whether the filter should be applied or not, default is FALSE.
        """

    @property
    def Command(self) -> str:
        """
        is the command which should be executed, the type of command depends on the CommandType.
        
        In case of a CommandType of CommandType.COMMAND, means in case the Command specifies an SQL statement, the inherited com.sun.star.sdbc.RowSet.EscapeProcessing becomes relevant:
        It then can be to used to specify whether the SQL statement should be analyzed on the client side before sending it to the database server.
        The default value for com.sun.star.sdbc.RowSet.EscapeProcessing is TRUE. By switching it to FALSE, you can pass backend-specific SQL statements, which are not standard SQL, to your database.
        """

    @property
    def CommandType(self) -> int:
        """
        specifies the type of the command to be executed to retrieve a result set.
        
        Command needs to be interpreted depending on the value of this property.
        
        This property is only meaningful together with the Command property, thus either both or none of them are present.
        """

    @property
    def DataSourceName(self) -> str:
        """
        is the name of the data source to use, this could be a named data source or the URL of a data access component.
        """

    @property
    def EscapeProcessing(self) -> bool:
        """
        specifies if the Command should be analyzed on the client side before sending it to the database server.
        
        The default value of this property is TRUE. By switching it to FALSE, you can pass backend-specific SQL statements, which are not standard SQL, to your database.
        
        This property is usually present together with the Command and CommandType properties, and is evaluated if and only if CommandType equals CommandType.COMMAND.
        """

    @property
    def Filter(self) -> str:
        """
        specifies an additional filter to optionally use.
        
        The Filter string has to form a SQL WHERE-clause, without the WHERE-string itself.
        
        If a DataSourceName, Command and CommandType are specified, a RowSet can be created with this information. If the results provided by the row set are to be additionally filtered, the Filter property can be used.
        
        Note that the Filter property does not make sense if a resultSet has been specified in the DataAccessDescriptor.
        """

    @property
    def GroupBy(self) -> str:
        """
        additional group by for the row set
        """

    @property
    def HavingClause(self) -> str:
        """
        additional having clause for the row set
        """

    @property
    def Order(self) -> str:
        """
        is an additional sort order definition for a row set.
        """

    @property
    def RowLimit(self) -> int:
        """
        specifies the maximal count of rows which should be fetched.
        
        A value of zero implies that no limit exists.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .time import Time as Time_604e0855


class TimeWithTimezone(object):
    """
    Struct Class

    represents a combined time value with time zone.
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API TimeWithTimezone <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1TimeWithTimezone.html>`_
    """
    typeName: Literal['com.sun.star.util.TimeWithTimezone']

    def __init__(self, TimeInTZ: typing.Optional[Time_604e0855] = ..., Timezone: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            TimeInTZ (Time, optional): TimeInTZ value.
            Timezone (int, optional): Timezone value.
        """


    @property
    def TimeInTZ(self) -> Time_604e0855:
        """
        the time (in TimeZone)
        """


    @property
    def Timezone(self) -> int:
        """
        contains the time zone, as signed offset in minutes from UTC, that is east of UTC, that is the amount of minutes that should be added to UTC time to obtain the time in that timezone.
        
        To obtain UTC time from TimeInTZ, you need to subtract TimeZone minutes.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.presentation
from typing_extensions import Literal
"""
Const


See Also:
    `API EffectCommands <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1presentation_1_1EffectCommands.html>`_
"""
CUSTOM: Literal[0]
"""
the command is user defined
"""
VERB: Literal[1]
"""
the command is an OLE verb.

Required parameters are \"Verb\" of type long that specifies the verb to execute.
"""
PLAY: Literal[2]
"""
the command starts playing on a media object.

Optional parameters are \"MediaTime\" of type double that specifies the start time in milliseconds. If not given, play continues at last position known.
"""
TOGGLEPAUSE: Literal[3]
"""
the command toggles the pause status on a media object.
"""
STOP: Literal[4]
"""
the command stops the animation on a media object
"""
STOPAUDIO: Literal[5]
"""
the command stops all currently running sound effects.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.io
from .x_active_data_source import XActiveDataSource as XActiveDataSource_d1900c7f
from .x_connectable import XConnectable as XConnectable_980a0a96
from .x_object_output_stream import XObjectOutputStream as XObjectOutputStream_ee190d8c

class ObjectOutputStream(XActiveDataSource_d1900c7f, XConnectable_980a0a96, XObjectOutputStream_ee190d8c):
    """
    Service Class

    is a stream which allows writing the data of persistent objects.
    
    Implementations of this service must fulfill the specifications of the DataOutputStream service; furthermore, the stream needs to be chained to a XMarkableStream. Therefore, it also provides the XMarkableStream interface, but it delegates the calls to the chained object. The written objects are held until this instance is destroyed. The references to the objects are written as four-byte integers and begin at 1. Data format is written:

    See Also:
        `API ObjectOutputStream <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1io_1_1ObjectOutputStream.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from ..accessibility.x_accessible import XAccessible as XAccessible_1cbc0eb6
from .x_control import XControl as XControl_7a9c098d
from .x_view import XView as XView_5f670847
from .x_window import XWindow as XWindow_713b0924

class UnoControl(XAccessible_1cbc0eb6, XControl_7a9c098d, XView_5f670847, XWindow_713b0924):
    """
    Service Class

    specifies an abstract control.
    
    All components which implement this service can be integrated in a windowing environment. This service describes the controller of the Smalltalk model view controller design.
    
    You must set a model and a stub to the UnoControl before using other methods. The implementation only allows the change of the graphics (XView) if the window is not visible. The change of the graphics in visible state should redirect the output to these graphics, but this behavior is implementation-specific.
    
    The change of data directly at the control may not affect the model data. To ensure this behavior, modify the data of the model.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API UnoControl <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControl.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form.runtime
from typing_extensions import Literal
"""
Const

specifies the operations on a user interface form, as supported by the XFormOperations interface.

**since**

    OOo 2.2

See Also:
    `API FormFeature <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1FormFeature.html>`_
"""
MoveAbsolute: Literal[1]
"""
moves the form to a record given by absolute position.

This operation cannot be executed without arguments. When executing it (i.e. when calling com.sun.star.form.runtime.XFormOperations.executeWithArguments()), you need to specify a parameter named Position of type long, which denotes the position to move the form to.
"""
TotalRecords: Literal[2]
"""
determines the number of total records in the form, including the potentially active insertion row.

This is not strictly an operation you can do on a form, but rather a state you can retrieve (and display to the user) using the XFormOperations's respective methods.

The state obtained here is a string, not a number. This is because in an UI form, the fact that the current record count is not yet known (since not all records have been visited, yet) is indicated by an asterisk (*) besides the record count.
"""
MoveToFirst: Literal[3]
"""
moves the form to the first record
"""
MoveToPrevious: Literal[4]
"""
moves the form to the record before the current record, if there is any
"""
MoveToNext: Literal[5]
"""
moves the form to the record after the current record, if there is any
"""
MoveToLast: Literal[6]
"""
moves the form to the last record
"""
MoveToInsertRow: Literal[7]
"""
moves the form to the insertion row, if privileges allow
"""
SaveRecordChanges: Literal[8]
"""
saves all changes in the form's current record, including changes in the current control which had not yet been committed to the form
"""
UndoRecordChanges: Literal[9]
"""
reverts all changes in the form's current record, including changes in the current control which had not yet been committed to the form
"""
DeleteRecord: Literal[10]
"""
deletes the current record, while honoring any registered com.sun.star.form.XConfirmDeleteListeners
"""
ReloadForm: Literal[11]
"""
reloads the form content
"""
SortAscending: Literal[12]
"""
sorts the form ascending by the field which the active form control is bound to.
"""
SortDescending: Literal[13]
"""
sorts the form descending by the field which the active form control is bound to.
"""
InteractiveSort: Literal[14]
"""
opens a dialog which allows the user to interactively specify a form sorting order
"""
AutoFilter: Literal[15]
"""
adds a filter to the form, which is defined by the active form control and its current value

For instance, if the currently active form control is bound to a table field named Price, and currently has a value of 100, then invoking the AutoFilter operation will put an additional filter Price = 100 on the form.
"""
InteractiveFilter: Literal[16]
"""
opens a dialog which allows the user to interactively specify a form filter
"""
ToggleApplyFilter: Literal[17]
"""
toggles the com.sun.star.sdb.RowSet.ApplyFilter property of the form.
"""
RemoveFilterAndSort: Literal[18]
"""
removes all filter and sort criteria put on the form.

Note that this does not apply to criteria which are part of the form's data source. That is, if you bind the form to the SQL command SELECT * FROM Articles WHERE Price > 100, then the Price > 100 filter will not be removed.

Effectively, this operation resets the com.sun.star.sdb.RowSet.Filter and com.sun.star.sdb.RowSet.Order properties of the form.
"""
RefreshCurrentControl: Literal[19]
"""
refreshes the current control

Basically, this means calling XRefreshable.refresh on the current control, if it supports this interface.

**since**

    OOo 3.1
"""

